@@ -1,34 +1,31 @@
-m4_divert(-1)
-
 # C++ skeleton for Bison
 
-# Copyright (C) 2002, 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
+# Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2009, 2010
+# Free Software Foundation, Inc.
 
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # We do want M4 expansion after # for CPP macros.
 m4_changecom()
-m4_divert(0)dnl
-@output b4_dir_prefix[]position.hh
+m4_divert_push(0)dnl
+@output(b4_dir_prefix[]position.hh@)@
 b4_copyright([Positions for Bison parsers in C++],
-  [2002, 2003, 2004, 2005, 2006])[
+             [2002, 2003, 2004, 2005, 2006, 2007, 2009, 2010])[
 
 /**
  ** \file position.hh
- ** Define the ]b4_namespace[::position class.
+ ** Define the ]b4_namespace_ref[::position class.
  */
 
 #ifndef BISON_POSITION_HH
@@ -38,8 +35,7 @@ b4_copyright([Positions for Bison parsers in C++],
 # include <string>
 # include <algorithm>
 
-namespace ]b4_namespace[
-{
+]b4_namespace_open[
   /// Abstract a position.
   class position
   {
@@ -53,7 +49,7 @@ namespace ]b4_namespace[
 
 ])[
     /// Initialization.
-    inline void initialize (]b4_filename_type[* fn)
+    inline void initialize (]b4_percent_define_get([[filename_type]])[* fn)
     {
       filename = fn;
       line = ]b4_location_initial_line[;
@@ -79,7 +75,7 @@ namespace ]b4_namespace[
 
   public:
     /// File name to which this position refers.
-    ]b4_filename_type[* filename;
+    ]b4_percent_define_get([[filename_type]])[* filename;
     /// Current line number.
     unsigned int line;
     /// Current column number.
@@ -115,15 +111,16 @@ namespace ]b4_namespace[
   {
     return begin + -width;
   }
-]m4_if(b4_define_location_comparison, [1], [[
+]b4_percent_define_flag_if([[define_location_comparison]], [[
   /// Compare two position objects.
   inline bool
   operator== (const position& pos1, const position& pos2)
   {
-    return
-      (pos1.filename == pos2.filename
-       || pos1.filename && pos2.filename && *pos1.filename == *pos2.filename)
-      && pos1.line == pos2.line && pos1.column == pos2.column;
+    return (pos1.line == pos2.line
+            && pos1.column == pos2.column
+            && (pos1.filename == pos2.filename
+                || (pos1.filename && pos2.filename
+                    && *pos1.filename == *pos2.filename)));
   }
 
   /// Compare two position objects.
@@ -145,15 +142,15 @@ namespace ]b4_namespace[
     return ostr << pos.line << '.' << pos.column;
   }
 
-}
+]b4_namespace_close[
 #endif // not BISON_POSITION_HH]
-@output b4_dir_prefix[]location.hh
+@output(b4_dir_prefix[]location.hh@)@
 b4_copyright([Locations for Bison parsers in C++],
-  [2002, 2003, 2004, 2005, 2006])[
+             [2002, 2003, 2004, 2005, 2006, 2007, 2009, 2010])[
 
 /**
  ** \file location.hh
- ** Define the ]b4_namespace[::location class.
+ ** Define the ]b4_namespace_ref[::location class.
  */
 
 #ifndef BISON_LOCATION_HH
@@ -163,8 +160,7 @@ b4_copyright([Locations for Bison parsers in C++],
 # include <string>
 # include "position.hh"
 
-namespace ]b4_namespace[
-{
+]b4_namespace_open[
 
   /// Abstract a location.
   class location
@@ -179,7 +175,7 @@ namespace ]b4_namespace[
 
 ])[
     /// Initialization.
-    inline void initialize (]b4_filename_type[* fn)
+    inline void initialize (]b4_percent_define_get([[filename_type]])[* fn)
     {
       begin.initialize (fn);
       end = begin;
@@ -237,7 +233,7 @@ namespace ]b4_namespace[
     res.columns (width);
     return res;
   }
-]m4_if(b4_define_location_comparison, [1], [[
+]b4_percent_define_flag_if([[define_location_comparison]], [[
   /// Compare two location objects.
   inline bool
   operator== (const location& loc1, const location& loc2)
@@ -273,8 +269,8 @@ namespace ]b4_namespace[
     return ostr;
   }
 
-}
+]b4_namespace_close[
 
 #endif // not BISON_LOCATION_HH]
-m4_divert(-1)
+m4_divert_pop(0)
 m4_changecom([#])
