@@ -1,7 +1,7 @@
 /* Lists of symbols for Bison
 
-   Copyright (C) 2002, 2005-2007, 2009-2010 Free Software Foundation,
-   Inc.
+   Copyright (C) 2002, 2005, 2006, 2007, 2009, 2010 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
